@@ -2,7 +2,7 @@ from typing import Optional, List, Union
 import time
 from hein_robots.robotics import Location, Twist, Wrench, Cartesian, Orientation, Units, Frame
 from hein_robots.base import robot_arms
-from hein_robots.base.actuators import Actuator
+from hein_robots.kinova.kinova_gripper import KinovaGripper
 from hein_robots.kinova.kortex import KortexConnection, Base_pb2, ControlConfig_pb2
 
 
@@ -14,6 +14,7 @@ class KinovaGen3Arm(robot_arms.RobotArm):
     def __init__(self, host: str = '192.168.1.10', port: int = 10000, username: str = 'admin', password: str = 'admin', connect: bool = True,
                  default_velocity: float = 250, max_velocity: float = 500, position_units: str = Units.MILLIMETERS):
         self.connection = KortexConnection(host, port, username=username, password=password, connect=connect)
+        self.gripper = KinovaGripper(self.connection)
         self.last_feedback = None
         self.last_feedback_time = 0
         self.last_gripper_feedback = None
@@ -46,7 +47,7 @@ class KinovaGen3Arm(robot_arms.RobotArm):
 
     @property
     def gripper_feedback(self):
-        return self.feedback.interconnect.gripper_feedback.motor[0]
+        return self.gripper.gripper_feedback
 
     @property
     def max_velocity(self) -> float:
@@ -120,11 +121,11 @@ class KinovaGen3Arm(robot_arms.RobotArm):
 
     @property
     def gripper_position(self) -> float:
-        return self.gripper_feedback.position
+        return self.gripper.position
 
     @property
     def gripper_velocity(self) -> float:
-        return self.gripper_feedback.velocity
+        return self.gripper.velocity
 
     @property
     def tool_configuration(self) -> ControlConfig_pb2.ToolConfiguration:
@@ -302,36 +303,13 @@ class KinovaGen3Arm(robot_arms.RobotArm):
         self.move_twist(**twist.dict, duration=duration, wait=wait, timeout=timeout)
 
     def wait_for_gripper_stop(self, timeout: Optional[float] = None):
-        if timeout is None:
-            timeout = self.connection.action_timeout
+        self.gripper.wait_for_stop(timeout)
 
-        start_time = time.time()
-
-        while time.time() - start_time < timeout:
-            if abs(self.gripper_velocity) < self.GRIPPER_VELOCITY_STOP_THRESHOLD:
-                time.sleep(self.GRIPPER_STOP_WAIT_TIME)
-                return
-
-        raise robot_arms.RobotArmGripperTimeoutError(f'Timeout while waiting for gripper to stop')
-
-    def open_gripper(self, position: Optional[Union[float, bool]] = None, duration: Optional[float] = None, wait: bool = True, timeout: Optional[float] = None):
+    def open_gripper(self, position: Optional[Union[float, bool]] = None, force: Optional[float] = None, velocity: Optional[float] = None,
+                     wait: bool = True, timeout: Optional[float] = None):
         if position is None:
             position = 0.0
         elif isinstance(position, bool):
             position = 0.0 if position else 1.0
 
-        command = Base_pb2.GripperCommand()
-        command.mode = Base_pb2.GRIPPER_POSITION
-
-        if duration is not None:
-            command.duration = round(duration)
-
-        finger = command.gripper.finger.add()
-        finger.finger_identifier = 1
-        finger.value = position
-
-        self.connection.execute_gripper_command(command)
-
-        if wait:
-            time.sleep(self.GRIPPER_WAIT_DELAY)
-            self.wait_for_gripper_stop(timeout=timeout)
+        self.gripper.move(position, force=force or self.gripper_default_force, velocity=velocity or self.gripper_default_velocity, timeout=timeout or 10.0)
